NXSConfigServer Tango Class Description

NXSConfigServer Class Identification : | NXSConfigServer Class Inheritance :
Contact | : at desy.de - jan.kotanski
Class Family | : Acquisition
Platform | : All Platforms
Bus | : Not Applicable
Manufacturer | : DESY
Manufacturer ref. | :
| Tango::DeviceImpl NXSConfigServer

NXSConfigServer Class Description :

NeXuS Configuration Server is a Tango Server with its implementation based
on a MySQL database. It allows to store XML configuration datasources
and components. It also gives possibility to select mandatory components
and perform the process of component merging.
Source code: https://github.com/nexdatas/nxsconfigserver/
Web page: https://nexdatas.github.io/nxsconfigserver/
NexDaTaS Web page: https://nexdatas.github.io